var host_8h =
[
    [ "isc::dhcp::AuthKey", "dd/d41/classisc_1_1dhcp_1_1AuthKey.html", "dd/d41/classisc_1_1dhcp_1_1AuthKey" ],
    [ "isc::dhcp::Host", "d7/dd1/classisc_1_1dhcp_1_1Host.html", "d7/dd1/classisc_1_1dhcp_1_1Host" ],
    [ "isc::dhcp::IPv6Resrv", "d5/d93/classisc_1_1dhcp_1_1IPv6Resrv.html", "d5/d93/classisc_1_1dhcp_1_1IPv6Resrv" ],
    [ "ConstHostCollection", "df/ded/host_8h.html#a3a0590637b8564211bbe4ec04b8764f6", null ],
    [ "ConstHostPtr", "df/ded/host_8h.html#aac9e74ed4d7d676331f7f70593b7bf92", null ],
    [ "HostCollection", "df/ded/host_8h.html#a6d058c67779e9e4f405facd2c6884601", null ],
    [ "HostID", "df/ded/host_8h.html#a9b02eea5ebd4f49ae45f01ca4df1be28", null ],
    [ "HostPtr", "df/ded/host_8h.html#a3146f56663eb0128509cc9664aaf4f32", null ],
    [ "IPv6ResrvCollection", "df/ded/host_8h.html#a8fd489667302d4e593d75d4e8bec048e", null ],
    [ "IPv6ResrvIterator", "df/ded/host_8h.html#a057c03921246239552258356489655c9", null ],
    [ "IPv6ResrvRange", "df/ded/host_8h.html#a6300bfe92da530f967615426732670a6", null ],
    [ "IPv6ResrvTuple", "df/ded/host_8h.html#abfdbc143012357cf531f07c2a3cf6afc", null ]
];